@@ -261,16 +261,14 @@ enum [[deprecated]] : int {
     SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 16, // QList<QCameraFormat>
     SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 18, // QList<QAudioFormat::SampleFormat>
     SBK_QTMULTIMEDIA_QLIST_QCAPTURABLEWINDOW_IDX             = 20, // QList<QCapturableWindow>
-    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 22, // QList<QObject*>
-    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 24, // QList<QByteArray>
-    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 26, // QList<QAudioDevice>
-    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 28, // QList<QCameraDevice>
-    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 30, // QList<QImageCapture::FileFormat>
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 32, // QList<QMediaMetaData>
-    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 34, // QList<QVariant>
-    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 36, // QList<QString>
-    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 38, // QMap<QString,QVariant>
-    SBK_QTMULTIMEDIA_CONVERTERS_IDX_COUNT                    = 40,
+    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 22, // QList<QAudioDevice>
+    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 24, // QList<QCameraDevice>
+    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 26, // QList<QImageCapture::FileFormat>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 28, // QList<QMediaMetaData>
+    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 30, // QList<QVariant>
+    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 32, // QList<QString>
+    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 34, // QMap<QString,QVariant>
+    SBK_QTMULTIMEDIA_CONVERTERS_IDX_COUNT                    = 36,
 };
 
 // Converter indices
@@ -286,16 +284,14 @@ enum : int {
     SBK_QtMultimedia_QList_QCameraFormat_IDX                 = 8, // QList<QCameraFormat>
     SBK_QtMultimedia_QList_QAudioFormat_SampleFormat_IDX     = 9, // QList<QAudioFormat::SampleFormat>
     SBK_QtMultimedia_QList_QCapturableWindow_IDX             = 10, // QList<QCapturableWindow>
-    SBK_QtMultimedia_QList_QObjectPTR_IDX                    = 11, // QList<QObject*>
-    SBK_QtMultimedia_QList_QByteArray_IDX                    = 12, // QList<QByteArray>
-    SBK_QtMultimedia_QList_QAudioDevice_IDX                  = 13, // QList<QAudioDevice>
-    SBK_QtMultimedia_QList_QCameraDevice_IDX                 = 14, // QList<QCameraDevice>
-    SBK_QtMultimedia_QList_QImageCapture_FileFormat_IDX      = 15, // QList<QImageCapture::FileFormat>
-    SBK_QtMultimedia_QList_QMediaMetaData_IDX                = 16, // QList<QMediaMetaData>
-    SBK_QtMultimedia_QList_QVariant_IDX                      = 17, // QList<QVariant>
-    SBK_QtMultimedia_QList_QString_IDX                       = 18, // QList<QString>
-    SBK_QtMultimedia_QMap_QString_QVariant_IDX               = 19, // QMap<QString,QVariant>
-    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 20,
+    SBK_QtMultimedia_QList_QAudioDevice_IDX                  = 11, // QList<QAudioDevice>
+    SBK_QtMultimedia_QList_QCameraDevice_IDX                 = 12, // QList<QCameraDevice>
+    SBK_QtMultimedia_QList_QImageCapture_FileFormat_IDX      = 13, // QList<QImageCapture::FileFormat>
+    SBK_QtMultimedia_QList_QMediaMetaData_IDX                = 14, // QList<QMediaMetaData>
+    SBK_QtMultimedia_QList_QVariant_IDX                      = 15, // QList<QVariant>
+    SBK_QtMultimedia_QList_QString_IDX                       = 16, // QList<QString>
+    SBK_QtMultimedia_QMap_QString_QVariant_IDX               = 17, // QMap<QString,QVariant>
+    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 18,
 };
 // Macros for type check
 
