@@ -394,27 +394,26 @@ enum [[deprecated]] : int {
     SBK_QTNETWORK_QMULTIHASH_QBYTEARRAY_QBYTEARRAY_IDX       = 26, // QMultiHash<QByteArray,QByteArray>
     SBK_QTNETWORK_QMULTIMAP_QBYTEARRAY_QBYTEARRAY_IDX        = 28, // QMultiMap<QByteArray,QByteArray>
     SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 30, // QHash<QString,QVariant>
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 32, // QList<QObject*>
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 34, // QMap<QString,QVariant>
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 36, // QList<QNetworkCookie>
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 38, // QList<QHstsPolicy>
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 40, // QList<QSslError>
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 42, // QList<QDnsDomainNameRecord>
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 44, // QList<QDnsHostAddressRecord>
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 46, // QList<QDnsMailExchangeRecord>
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 48, // QList<QDnsServiceRecord>
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 50, // QList<QDnsTextRecord>
-    SBK_QTNETWORK_QLIST_QDNSTLSASSOCIATIONRECORD_IDX         = 52, // QList<QDnsTlsAssociationRecord>
-    SBK_QTNETWORK_STD_PAIR_QHOSTADDRESS_INT_IDX              = 54, // std::pair<QHostAddress,int>
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 56, // QList<QString>
-    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 58, // QList<QSsl::ImplementedClass>
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 60, // QList<QOcspResponse>
-    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 62, // QList<QSsl::SupportedFeature>
-    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 64, // QList<QSsl::SslProtocol>
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 66, // QList<QSslCertificateExtension>
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 68, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 70, // QList<QVariant>
-    SBK_QTNETWORK_CONVERTERS_IDX_COUNT                       = 72,
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 32, // QMap<QString,QVariant>
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 34, // QList<QNetworkCookie>
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 36, // QList<QHstsPolicy>
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 38, // QList<QSslError>
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 40, // QList<QDnsDomainNameRecord>
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 42, // QList<QDnsHostAddressRecord>
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 44, // QList<QDnsMailExchangeRecord>
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 46, // QList<QDnsServiceRecord>
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 48, // QList<QDnsTextRecord>
+    SBK_QTNETWORK_QLIST_QDNSTLSASSOCIATIONRECORD_IDX         = 50, // QList<QDnsTlsAssociationRecord>
+    SBK_QTNETWORK_STD_PAIR_QHOSTADDRESS_INT_IDX              = 52, // std::pair<QHostAddress,int>
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 54, // QList<QString>
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 56, // QList<QSsl::ImplementedClass>
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 58, // QList<QOcspResponse>
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 60, // QList<QSsl::SupportedFeature>
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 62, // QList<QSsl::SslProtocol>
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 64, // QList<QSslCertificateExtension>
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 66, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 68, // QList<QVariant>
+    SBK_QTNETWORK_CONVERTERS_IDX_COUNT                       = 70,
 };
 
 // Converter indices
@@ -435,27 +434,26 @@ enum : int {
     SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX       = 13, // QMultiHash<QByteArray,QByteArray>
     SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX        = 14, // QMultiMap<QByteArray,QByteArray>
     SBK_QtNetwork_QHash_QString_QVariant_IDX                 = 15, // QHash<QString,QVariant>
-    SBK_QtNetwork_QList_QObjectPTR_IDX                       = 16, // QList<QObject*>
-    SBK_QtNetwork_QMap_QString_QVariant_IDX                  = 17, // QMap<QString,QVariant>
-    SBK_QtNetwork_QList_QNetworkCookie_IDX                   = 18, // QList<QNetworkCookie>
-    SBK_QtNetwork_QList_QHstsPolicy_IDX                      = 19, // QList<QHstsPolicy>
-    SBK_QtNetwork_QList_QSslError_IDX                        = 20, // QList<QSslError>
-    SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX             = 21, // QList<QDnsDomainNameRecord>
-    SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX            = 22, // QList<QDnsHostAddressRecord>
-    SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX           = 23, // QList<QDnsMailExchangeRecord>
-    SBK_QtNetwork_QList_QDnsServiceRecord_IDX                = 24, // QList<QDnsServiceRecord>
-    SBK_QtNetwork_QList_QDnsTextRecord_IDX                   = 25, // QList<QDnsTextRecord>
-    SBK_QtNetwork_QList_QDnsTlsAssociationRecord_IDX         = 26, // QList<QDnsTlsAssociationRecord>
-    SBK_QtNetwork_std_pair_QHostAddress_int_IDX              = 27, // std::pair<QHostAddress,int>
-    SBK_QtNetwork_QList_QString_IDX                          = 28, // QList<QString>
-    SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX            = 29, // QList<QSsl::ImplementedClass>
-    SBK_QtNetwork_QList_QOcspResponse_IDX                    = 30, // QList<QOcspResponse>
-    SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX            = 31, // QList<QSsl::SupportedFeature>
-    SBK_QtNetwork_QList_QSsl_SslProtocol_IDX                 = 32, // QList<QSsl::SslProtocol>
-    SBK_QtNetwork_QList_QSslCertificateExtension_IDX         = 33, // QList<QSslCertificateExtension>
-    SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX = 34, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
-    SBK_QtNetwork_QList_QVariant_IDX                         = 35, // QList<QVariant>
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 36,
+    SBK_QtNetwork_QMap_QString_QVariant_IDX                  = 16, // QMap<QString,QVariant>
+    SBK_QtNetwork_QList_QNetworkCookie_IDX                   = 17, // QList<QNetworkCookie>
+    SBK_QtNetwork_QList_QHstsPolicy_IDX                      = 18, // QList<QHstsPolicy>
+    SBK_QtNetwork_QList_QSslError_IDX                        = 19, // QList<QSslError>
+    SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX             = 20, // QList<QDnsDomainNameRecord>
+    SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX            = 21, // QList<QDnsHostAddressRecord>
+    SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX           = 22, // QList<QDnsMailExchangeRecord>
+    SBK_QtNetwork_QList_QDnsServiceRecord_IDX                = 23, // QList<QDnsServiceRecord>
+    SBK_QtNetwork_QList_QDnsTextRecord_IDX                   = 24, // QList<QDnsTextRecord>
+    SBK_QtNetwork_QList_QDnsTlsAssociationRecord_IDX         = 25, // QList<QDnsTlsAssociationRecord>
+    SBK_QtNetwork_std_pair_QHostAddress_int_IDX              = 26, // std::pair<QHostAddress,int>
+    SBK_QtNetwork_QList_QString_IDX                          = 27, // QList<QString>
+    SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX            = 28, // QList<QSsl::ImplementedClass>
+    SBK_QtNetwork_QList_QOcspResponse_IDX                    = 29, // QList<QOcspResponse>
+    SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX            = 30, // QList<QSsl::SupportedFeature>
+    SBK_QtNetwork_QList_QSsl_SslProtocol_IDX                 = 31, // QList<QSsl::SslProtocol>
+    SBK_QtNetwork_QList_QSslCertificateExtension_IDX         = 32, // QList<QSslCertificateExtension>
+    SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX = 33, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
+    SBK_QtNetwork_QList_QVariant_IDX                         = 34, // QList<QVariant>
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 35,
 };
 // Macros for type check
 
