@@ -18,10 +18,13 @@
 // Bound library includes
 #include <QtWebSockets/qwebsocketprotocol.h>
 #include <QtWebSockets/qwebsocketserver.h>
+
+QT_BEGIN_NAMESPACE
 class QMaskGenerator;
 class QWebSocket;
 class QWebSocketCorsAuthenticator;
 class QWebSocketHandshakeOptions;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -54,6 +57,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtWebSocketsTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtWebSocketsTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtWebSocketsModuleObject;
 
@@ -63,27 +69,23 @@ extern SbkConverter **SbkPySide6_QtWebSocketsTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTWEBSOCKETS_QLIST_INT_IDX                           = 0, // QList<int>
-    SBK_QTWEBSOCKETS_QLIST_QOBJECTPTR_IDX                    = 2, // QList<QObject*>
-    SBK_QTWEBSOCKETS_QLIST_QBYTEARRAY_IDX                    = 4, // QList<QByteArray>
-    SBK_QTWEBSOCKETS_QLIST_QSSLERROR_IDX                     = 6, // QList<QSslError>
-    SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX    = 8, // QList<QWebSocketProtocol::Version>
-    SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                      = 10, // QList<QVariant>
-    SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                       = 12, // QList<QString>
-    SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX               = 14, // QMap<QString,QVariant>
-    SBK_QTWEBSOCKETS_CONVERTERS_IDX_COUNT                    = 16,
+    SBK_QTWEBSOCKETS_QLIST_QSSLERROR_IDX                     = 2, // QList<QSslError>
+    SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX    = 4, // QList<QWebSocketProtocol::Version>
+    SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                      = 6, // QList<QVariant>
+    SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                       = 8, // QList<QString>
+    SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX               = 10, // QMap<QString,QVariant>
+    SBK_QTWEBSOCKETS_CONVERTERS_IDX_COUNT                    = 12,
 };
 
 // Converter indices
 enum : int {
     SBK_QtWebSockets_QList_int_IDX                           = 0, // QList<int>
-    SBK_QtWebSockets_QList_QObjectPTR_IDX                    = 1, // QList<QObject*>
-    SBK_QtWebSockets_QList_QByteArray_IDX                    = 2, // QList<QByteArray>
-    SBK_QtWebSockets_QList_QSslError_IDX                     = 3, // QList<QSslError>
-    SBK_QtWebSockets_QList_QWebSocketProtocol_Version_IDX    = 4, // QList<QWebSocketProtocol::Version>
-    SBK_QtWebSockets_QList_QVariant_IDX                      = 5, // QList<QVariant>
-    SBK_QtWebSockets_QList_QString_IDX                       = 6, // QList<QString>
-    SBK_QtWebSockets_QMap_QString_QVariant_IDX               = 7, // QMap<QString,QVariant>
-    SBK_QtWebSockets_CONVERTERS_IDX_COUNT                    = 8,
+    SBK_QtWebSockets_QList_QSslError_IDX                     = 1, // QList<QSslError>
+    SBK_QtWebSockets_QList_QWebSocketProtocol_Version_IDX    = 2, // QList<QWebSocketProtocol::Version>
+    SBK_QtWebSockets_QList_QVariant_IDX                      = 3, // QList<QVariant>
+    SBK_QtWebSockets_QList_QString_IDX                       = 4, // QList<QString>
+    SBK_QtWebSockets_QMap_QString_QVariant_IDX               = 5, // QMap<QString,QVariant>
+    SBK_QtWebSockets_CONVERTERS_IDX_COUNT                    = 6,
 };
 // Macros for type check
 
